@@ -141,20 +141,24 @@ g_buffered_output_stream_class_init (GBufferedOutputStreamClass *klass)
 
 /**
  * g_buffered_output_stream_get_buffer_size:
- * @stream:
+ * @stream: a #GBufferedOutputStream.
  * 
- * Returns: 
+ * Returns: the current size of the buffer.
  **/
 gsize
 g_buffered_output_stream_get_buffer_size (GBufferedOutputStream *stream)
 {
+  g_return_val_if_fail (G_IS_BUFFERED_OUTPUT_STREAM (stream), -1);
+
   return stream->priv->len;
 }
 
 /**
  * g_buffered_output_stream_set_buffer_size:
- * @stream:
- * @size:
+ * @stream: a #GBufferedOutputStream.
+ * @size: a #gsize.
+ *
+ * Sets the size of the internal buffer to @size.
  * 
  **/    
 void
@@ -163,6 +167,8 @@ g_buffered_output_stream_set_buffer_size (GBufferedOutputStream *stream,
 {
   GBufferedOutputStreamPrivate *priv;
   guint8 *buffer;
+  
+  g_return_if_fail (G_IS_BUFFERED_OUTPUT_STREAM (stream));
 
   priv = stream->priv;
   
@@ -179,7 +185,7 @@ g_buffered_output_stream_set_buffer_size (GBufferedOutputStream *stream,
     }
   else
     {
-      priv->buffer = g_malloc (size);;
+      priv->buffer = g_malloc (size);
       priv->len = size;
       priv->pos = 0;
     }
@@ -187,26 +193,33 @@ g_buffered_output_stream_set_buffer_size (GBufferedOutputStream *stream,
 
 /**
  * g_buffered_output_stream_get_auto_grow:
- * @stream:
+ * @stream: a #GBufferedOutputStream.
  * 
- * Returns: 
+ * Returns: %TRUE if the @stream's buffer automatically grows,
+ * %FALSE otherwise.
  **/  
 gboolean
 g_buffered_output_stream_get_auto_grow (GBufferedOutputStream *stream)
 {
+  g_return_val_if_fail (G_IS_BUFFERED_OUTPUT_STREAM (stream), FALSE);
+
   return stream->priv->auto_grow;
 }
 
 /**
  * g_buffered_output_stream_set_auto_grow:
- * @stream:
- * @auto_grow:
+ * @stream: a #GBufferedOutputStream.
+ * @auto_grow: a boolean.
+ *
+ * Sets whether or not the @stream's buffer should automatically grow.
  * 
- **/  
+ **/
 void
 g_buffered_output_stream_set_auto_grow (GBufferedOutputStream *stream,
 				       gboolean              auto_grow)
 {
+  g_return_if_fail (G_IS_BUFFERED_OUTPUT_STREAM (stream));
+
   stream->priv->auto_grow = auto_grow;
 }
 
@@ -288,16 +301,16 @@ g_buffered_output_stream_init (GBufferedOutputStream *stream)
 
 /**
  * g_buffered_output_stream_new:
- * @base_stream:
+ * @base_stream: a #GOutputStream.
  * 
- * Returns: 
+ * Returns: a #GOutputStream for the given @base_stream.
  **/  
 GOutputStream *
 g_buffered_output_stream_new (GOutputStream *base_stream)
 {
   GOutputStream *stream;
 
-  g_assert (base_stream != NULL);
+  g_return_val_if_fail (G_IS_OUTPUT_STREAM (base_stream), NULL);
 
   stream = g_object_new (G_TYPE_BUFFERED_OUTPUT_STREAM,
                          "base-stream", base_stream,
@@ -308,10 +321,10 @@ g_buffered_output_stream_new (GOutputStream *base_stream)
 
 /**
  * g_buffered_output_stream_new_sized:
- * @base_stream:
- * @size:
+ * @base_stream: a #GOutputStream.
+ * @size: a #gsize.
  * 
- * Returns: 
+ * Returns: a #GOutputStream with an internal buffer set to @size.
  **/  
 GOutputStream *
 g_buffered_output_stream_new_sized (GOutputStream *base_stream,
@@ -319,7 +332,7 @@ g_buffered_output_stream_new_sized (GOutputStream *base_stream,
 {
   GOutputStream *stream;
 
-  g_assert (base_stream != NULL);
+  g_return_val_if_fail (G_IS_OUTPUT_STREAM (base_stream), NULL);
 
   stream = g_object_new (G_TYPE_BUFFERED_OUTPUT_STREAM,
                          "base-stream", base_stream,
