@@ -76,6 +76,16 @@ get_registry_classes_key (const char *subdir,
   return value_utf8;
 }
 
+/**
+ * g_content_type_equals:
+ * @type1: a content type string.
+ * @type2: a content type string.
+ *
+ * Compares two content types for equality.
+ *
+ * Returns: %TRUE if the two strings are identical or equivalent,
+ * %FALSE otherwise.
+ **/  
 gboolean
 g_content_type_equals (const char *type1,
 		       const char *type2)
@@ -101,6 +111,16 @@ g_content_type_equals (const char *type1,
   return res;
 }
 
+/**
+ * g_content_type_is_a:
+ * @type: a content type string. a content type string.
+ * @supertype: a string.
+ *
+ * Determines if @type is a subset of @supertype.  
+ *
+ * Returns: %TRUE if @type is a kind of @supertype,
+ * %FALSE otherwise. 
+ **/  
 gboolean
 g_content_type_is_a (const char   *type,
 		     const char   *supertype)
@@ -123,6 +143,12 @@ g_content_type_is_a (const char   *type,
   return res;
 }
 
+/**
+ * g_content_type_is_unknown:
+ * @type: a content type string. a content type string.
+ * 
+ * Returns:
+ **/  
 gboolean
 g_content_type_is_unknown (const char *type)
 {
@@ -131,6 +157,12 @@ g_content_type_is_unknown (const char *type)
   return strcmp ("*", type) == 0;
 }
 
+/**
+ * g_content_type_get_description:
+ * @type: a content type string. a content type string.
+ * 
+ * Returns: a short description of the content type @type. 
+ **/  
 char *
 g_content_type_get_description (const char *type)
 {
@@ -154,6 +186,12 @@ g_content_type_get_description (const char *type)
   return g_strdup_printf (_("%s filetype"), type);
 }
 
+/**
+ * g_content_type_get_mime_type:
+ * @type: a content type string. a content type string.
+ * 
+ * Returns: the registered mime-type for the given @type.
+ **/  
 char *
 g_content_type_get_mime_type (const char   *type)
 {
@@ -173,6 +211,12 @@ g_content_type_get_mime_type (const char   *type)
   return g_strdup ("application/octet-stream");
 }
 
+/**
+ * g_content_type_get_icon:
+ * @type: a content type string. a content type string.
+ * 
+ * Returns: #GIcon corresponding to the content type.
+ **/  
 GIcon *
 g_content_type_get_icon (const char   *type)
 {
@@ -188,6 +232,14 @@ g_content_type_get_icon (const char   *type)
   return NULL;
 }
 
+/**
+ * g_content_type_can_be_executable:
+ * @type: a content type string.
+ * 
+ * Returns: %TRUE if the file type corresponds to something that
+ * can be executable, %FALSE otherwise. Note that for instance
+ * things like textfiles can be executables (i.e. scripts)
+ **/  
 gboolean
 g_content_type_can_be_executable (const char   *type)
 {
@@ -214,6 +266,18 @@ looks_like_text (const guchar *data, gsize data_size)
   return TRUE;
 }
 
+/**
+ * g_content_type_guess:
+ * @filename: a string.
+ * @data: a stream of data.
+ * @data_size: the size of @data.
+ * @result_uncertain: a flag indicating the certainty of the 
+ * result.
+ * 
+ * Returns: a string indicating a guessed content type for the 
+ * given data. If the function is uncertain, @result_uncertain 
+ * will be set to %TRUE.
+ **/  
 char *
 g_content_type_guess (const char   *filename,
 		      const guchar *data,
@@ -244,6 +308,11 @@ g_content_type_guess (const char   *filename,
   return g_strdup ("*");
 }
 
+/**
+ * g_content_types_get_registered:
+ * 
+ * Returns: #GList of the registered content types.
+ **/  
 GList *
 g_content_types_get_registered (void)
 {
@@ -338,13 +407,6 @@ _g_unix_content_type_get_parents (const char *type)
   return (char **)g_ptr_array_free (array, FALSE);
 }
 
-/**
- * g_content_type_equals:
- * @type1:
- * @type2:
- * 
- * Returns: 
- **/  
 gboolean
 g_content_type_equals (const char   *type1,
 		       const char   *type2)
@@ -361,13 +423,6 @@ g_content_type_equals (const char   *type1,
   return res;
 }
 
-/**
- * g_content_type_is_a:
- * @type:
- * @supertype:
- * 
- * Returns: 
- **/  
 gboolean
 g_content_type_is_a (const char   *type,
 		     const char   *supertype)
@@ -384,13 +439,6 @@ g_content_type_is_a (const char   *type,
   return res;
 }
 
-
-/**
- * g_content_type_is_unknown:
- * @type:
- * 
- * Returns: 
- **/  
 gboolean
 g_content_type_is_unknown (const char *type)
 {
@@ -402,7 +450,7 @@ g_content_type_is_unknown (const char *type)
 
 typedef enum {
   MIME_TAG_TYPE_OTHER,
-  MIME_TAG_TYPE_COMMENT,
+  MIME_TAG_TYPE_COMMENT
 } MimeTagType;
 
 typedef struct {
@@ -500,7 +548,7 @@ load_comment_for_mime_helper (const char *dir, const char *basename)
   GMarkupParser parser = {
     mime_info_start_element,
     mime_info_end_element,
-    mime_info_text,
+    mime_info_text
   };
 
   filename = g_build_filename (dir, "mime", basename, NULL);
@@ -555,13 +603,6 @@ load_comment_for_mime (const char *mimetype)
   return g_strdup_printf (_("%s type"), mimetype);
 }
 
-
-/**
- * g_content_type_get_description:
- * @type:
- * 
- * Returns: 
- **/  
 char *
 g_content_type_get_description (const char *type)
 {
@@ -592,12 +633,6 @@ g_content_type_get_description (const char *type)
   return comment;
 }
 
-/**
- * g_content_type_get_mime_type:
- * @type:
- * 
- * Returns: 
- **/  
 char *
 g_content_type_get_mime_type (const char   *type)
 {
@@ -606,12 +641,6 @@ g_content_type_get_mime_type (const char   *type)
   return g_strdup (type);
 }
 
-/**
- * g_content_type_get_icon:
- * @type:
- * 
- * Returns: #GIcon corresponding to the content type.
- **/  
 GIcon *
 g_content_type_get_icon (const char   *type)
 {
@@ -621,10 +650,9 @@ g_content_type_get_icon (const char   *type)
   return NULL;
 }
 
-
 /**
  * g_content_type_can_be_executable:
- * @type:
+ * @type: a content type string.
  * 
  * Returns: %TRUE if the file type corresponds to something that
  * can be executable, %FALSE otherwise. Note that for instance
@@ -654,16 +682,6 @@ looks_like_text (const guchar *data, gsize data_size)
   return TRUE;
 }
 
-
-/**
- * g_content_type_guess:
- * @filename:
- * @data:
- * @data_size:
- * @result_uncertain:
- * 
- * Returns: 
- **/  
 char *
 g_content_type_guess (const char   *filename,
 		      const guchar *data,
@@ -818,12 +836,6 @@ enumerate_mimetypes_dir (const char *dir, GHashTable *mimetypes)
   g_free (mimedir);
 }
 
-
-/**
- * g_content_types_get_registered:
- * 
- * Returns: #GList containing all of the registered content types.
- **/  
 GList *
 g_content_types_get_registered (void)
 {
