@@ -141,7 +141,7 @@ g_desktop_app_info_init (GDesktopAppInfo *local)
 
 /**
  * g_desktop_app_info_new_from_filename:
- * @filename:
+ * @filename: a string containing a file name.
  * 
  * Returns: a new #GDesktopAppInfo or %NULL on error.
  **/
@@ -1019,7 +1019,7 @@ update_default_list (const char *desktop_id, const char *content_type, gboolean
 {
   char *dirname, *filename;
   GKeyFile *key_file;
-  gboolean load_succeeded, res;;
+  gboolean load_succeeded, res;
   char **old_list;
   char **list;
   gsize length, data_size;
@@ -1346,8 +1346,8 @@ g_desktop_app_info_remove_supports_type (GAppInfo           *appinfo,
  * @commandline:
  * @application_name:
  * @flags:
- * @error:
- * 
+ * @error: a #GError location to store the error occuring, or %NULL to 
+ * ignore.
  * Returns: new #GAppInfo for given command.
  **/
 GAppInfo *
@@ -1859,9 +1859,7 @@ mime_info_cache_dir_init (MimeInfoCacheDir *dir)
   
   return;
  error:
-  if (filename)
-    g_free (filename);
-  
+  g_free (filename);
   g_key_file_free (key_file);
   
   if (mime_types != NULL)
@@ -1941,9 +1939,7 @@ mime_info_cache_dir_init_defaults_list (MimeInfoCacheDir *dir)
   
   return;
  error:
-  if (filename)
-    g_free (filename);
-  
+  g_free (filename);
   g_key_file_free (key_file);
   
   if (mime_types != NULL)
