@@ -27,9 +27,11 @@
 #include <string.h>
 #include <errno.h>
 #include <fcntl.h>
-#include <sys/types.h>
 #include <unistd.h>
 
+#if HAVE_SYS_STATFS_H
+#include <sys/statfs.h>
+#endif
 #if HAVE_SYS_STATVFS_H
 #include <sys/statvfs.h>
 #endif
@@ -42,6 +44,28 @@
 #include <sys/mount.h>
 #endif
 
+#if defined(HAVE_STATFS) && defined(HAVE_STATVFS)
+/* Some systems have both statfs and statvfs, pick the
+   most "native" for these */
+# if defined(sun) && defined(__SVR4)
+   /* on solaris, statfs doesn't even have the
+      f_bavail field */
+#  define USE_STATVFS
+# else
+  /* at least on linux, statfs is the actual syscall */
+#  define USE_STATFS
+# endif
+
+#elif defined(HAVE_STATFS)
+
+# define USE_STATFS
+
+#elif defined(HAVE_STATVFS)
+
+# define USE_STATVFS
+
+#endif
+
 #include "glocalfile.h"
 #include "glocalfileinfo.h"
 #include "glocalfileenumerator.h"
@@ -520,7 +544,7 @@ g_local_file_get_child_for_display_name (GFile        *file,
   return new_file;
 }
 
-#if HAVE_STATFS
+#ifdef USE_STATFS
 static const char *
 get_fs_type (long f_type)
 {
@@ -717,17 +741,17 @@ g_local_file_query_filesystem_info (GFile                *file,
   int statfs_result;
   gboolean no_size;
   guint64 block_size;
-#if HAVE_STATFS
+#ifdef USE_STATFS
   struct statfs statfs_buffer;
   const char *fstype;
-#elif HAVE_STATVFS
+#elif defined(USE_STATVFS)
   struct statvfs statfs_buffer;
 #endif
   GFileAttributeMatcher *attribute_matcher;
 	
   no_size = FALSE;
   
-#if HAVE_STATFS
+#ifdef USE_STATFS
   
 #if STATFS_ARGS == 2
   statfs_result = statfs (local->filename, &statfs_buffer);
@@ -748,8 +772,8 @@ g_local_file_query_filesystem_info (GFile                *file,
     no_size = TRUE;
 #endif
   
-#elif HAVE_STATVFS
-  statfs_result = statvfs (unescaped_path, &statfs_buffer);
+#elif defined(USE_STATVFS)
+  statfs_result = statvfs (local->filename, &statfs_buffer);
   block_size = statfs_buffer.f_frsize; 
 #endif
 
@@ -773,7 +797,7 @@ g_local_file_query_filesystem_info (GFile                *file,
 					G_FILE_ATTRIBUTE_FS_SIZE))
     g_file_info_set_attribute_uint64 (info, G_FILE_ATTRIBUTE_FS_SIZE, block_size * statfs_buffer.f_blocks);
 
-#if HAVE_STATFS
+#ifdef USE_STATFS
   fstype = get_fs_type (statfs_buffer.f_type);
   if (fstype &&
       g_file_attribute_matcher_matches (attribute_matcher,
@@ -1468,11 +1492,13 @@ g_local_file_trash (GFile *file,
     fd = open (infofile, O_CREAT | O_EXCL, 0666);
   } while (fd == -1 && errno == EEXIST);
 
+  g_free (basename);
+  g_free (infodir);
+
   if (fd == -1)
     {
       g_free (filesdir);
       g_free (topdir);
-      g_free (infodir);
       g_free (trashname);
       g_free (infofile);
       
@@ -1495,7 +1521,6 @@ g_local_file_trash (GFile *file,
   if (g_rename (local->filename, trashfile) == -1)
     {
       g_free (topdir);
-      g_free (infodir);
       g_free (trashname);
       g_free (infofile);
       g_free (trashfile);
@@ -1531,8 +1556,10 @@ g_local_file_trash (GFile *file,
 
   g_file_set_contents (infofile, data, -1, NULL);
   g_free (infofile);
+  g_free (data);
   
   g_free (original_name_escaped);
+  g_free (trashname);
   
   return TRUE;
 }
